firebase_auth_platform_interface library
Classes
- ActionCodeInfo
-
A response from calling
checkActionCode. - ActionCodeInfoData
- The data associated with the action code.
- ActionCodeSettings
- Interface that defines the required continue/state URL with optional Android and iOS bundle identifiers.
- AdditionalUserInfo
- A structure containing additional user information from a federated identity provider.
- AppleAuthCredential
- The auth credential returned from calling AppleAuthProvider.credential.
- AppleAuthProvider
- This class should be used to either create a new Apple credential with an access code, or use the provider to trigger user authentication flows.
- AppleFullPersonName
- AuthCredential
- Interface that represents the credentials returned by an auth provider. Implementations specify the details about each auth provider's credential requirements.
- AuthProvider
- A base class which all providers must extend.
- ConfirmationResultPlatform
-
Interface for
ConfirmationResultimplementations. - EmailAuthCredential
- The auth credential returned from calling EmailAuthProvider.credential.
- EmailAuthProvider
- A EmailAuthCredential can be created by calling EmailAuthProvider.credential with an email and password.
- FacebookAuthCredential
- The auth credential returned from calling FacebookAuthProvider.credential.
- FacebookAuthProvider
- This class should be used to either create a new Facebook credential with an access code, or use the provider to trigger user authentication flows.
- FirebaseAuthPlatform
-
The interface that implementations of
firebase_authmust extend. - GameCenterAuthCredential
- The auth credential returned from calling GameCenterAuthProvider.credential.
- GameCenterAuthProvider
- This class should be used to create a new Game Center credential to trigger an authentication flow on Apple platform.
- GithubAuthCredential
- The auth credential returned from calling GithubAuthProvider.credential.
- GithubAuthProvider
- This class should be used to either create a new GitHub credential with an access code, or use the provider to trigger user authentication flows.
- GoogleAuthCredential
- The auth credential returned from calling GoogleAuthProvider.credential.
- GoogleAuthProvider
- This class should be used to either create a new Google credential with an access code, or use the provider to trigger user authentication flows.
- IdTokenResult
-
Interface representing ID token result obtained from
getIdTokenResult. It contains the ID token JWT string and other helper properties for getting different data associated with the token as well as all the decoded payload claims. - MicrosoftAuthProvider
- This class should be used to either create a new Microsoft credential with an access code, or use the provider to trigger user authentication flows.
- MultiFactorAssertionPlatform
- Represents an assertion that the Firebase Authentication server can use to authenticate a user as part of a multi-factor flow.
- MultiFactorInfo
- Represents a single second factor means for the user.
- MultiFactorPlatform
-
The platform defining the interface of multi-factor related
properties and operations pertaining to a
User. - MultiFactorResolverPlatform
- Utility class that contains methods to resolve second factor requirements on users that have opted into two-factor authentication.
- MultiFactorSession
- Identifies the current session to enroll a second factor or to complete sign in when previously enrolled.
- OAuthCredential
- A generic OAuth credential.
- OAuthProvider
- A generic provider instance.
- PasswordPolicy
- PasswordPolicyApi
- PasswordPolicyImpl
- PasswordValidationStatus
- PhoneAuthCredential
- The auth credential returned from calling PhoneAuthProvider.credential.
- PhoneAuthProvider
- This class should be used to either create a new Phone credential with an verification ID and SMS code.
- PhoneMultiFactorGeneratorPlatform
- Helper class used to generate PhoneMultiFactorAssertions.
- PhoneMultiFactorInfo
- Represents the information for a phone second factor.
- PigeonIdTokenResult
- PigeonUserDetails
- PigeonUserInfo
- PlayGamesAuthCredential
- The auth credential returned from calling PlayGamesAuthProvider.credential.
- PlayGamesAuthProvider
- This class should be used to either create a new Play Games credential with an access code, or use the provider to trigger user authentication flows.
- RecaptchaVerifierFactoryPlatform
- A factory platform class for Recaptcha Verifier implementations.
- SAMLAuthProvider
- Security Assertion Markup Language based provider.
- TotpMultiFactorGeneratorPlatform
- Helper class used to generate TotpMultiFactorAssertions.
- TotpMultiFactorInfo
- Represents the information for a phone second factor.
- TotpSecretPlatform
- Helper class used to generate TotpMultiFactorAssertions.
- TwitterAuthCredential
- The auth credential returned from calling TwitterAuthProvider.credential.
- TwitterAuthProvider
- This class should be used to either create a new Twitter credential with an access code, or use the provider to trigger user authentication flows.
- UserCredentialPlatform
-
A UserCredential is returned from authentication requests such as
createUserWithEmailAndPassword. - UserInfo
- User profile information, visible only to the Firebase project's apps.
- UserMetadata
- Interface representing a user's metadata.
- UserPlatform
- A user account.
- YahooAuthCredential
- The auth credential returned from calling YahooAuthProvider.credential.
- YahooAuthProvider
- This class should be used to either create a new Yahoo credential with an access code, or use the provider to trigger user authentication flows.
Enums
- ActionCodeInfoOperation
-
The type of operation that generated the action code from calling
checkActionCode. - Persistence
- An enumeration of the possible persistence mechanism types.
- RecaptchaVerifierSize
- A enum to represent a reCAPTCHA widget size.
- RecaptchaVerifierTheme
- A enum to represent a reCAPTCHA widget theme.
Typedefs
- PhoneCodeAutoRetrievalTimeout = void Function(String verificationId)
- Typedef for handling automatic phone number timeout resolution.
- PhoneCodeSent = void Function(String verificationId, int? forceResendingToken)
- Typedef for handling when Firebase sends a SMS code to the provided phone number.
- PhoneVerificationCompleted = void Function(PhoneAuthCredential phoneAuthCredential)
- Typedef for an automatic phone number resolution.
- PhoneVerificationFailed = void Function(FirebaseAuthException error)
- Typedef for handling errors via phone number verification.
- RecaptchaVerifierOnError = void Function(FirebaseAuthException exception)
- Called when the reCAPTCHA widget errors (such as a network error).
- RecaptchaVerifierOnExpired = void Function()
- Called when the time to complete the reCAPTCHA widget expires.
- RecaptchaVerifierOnSuccess = void Function()
- Called on successful completion of the reCAPTCHA widget.
Exceptions / Errors
- FirebaseAuthException
- Generic exception related to Firebase Authentication. Check the error code and message for more details.
- FirebaseAuthMultiFactorExceptionPlatform
- MultiFactor exception related to Firebase Authentication. Check the error code and message for more details.