AppleFullPersonName class

Constructors

AppleFullPersonName({String? givenName, String? familyName, String? middleName, String? nickname, String? namePrefix, String? nameSuffix})

Properties

familyName String?
final
givenName String?
final
hashCode int
The hash code for this object.
no setterinherited
middleName String?
final
namePrefix String?
final
nameSuffix String?
final
nickname String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited